@@ -15,10 +15,15 @@ def normalize_path(path: str) -> str:
     return strip_leading_slash(path)
 
 
-def join_url(base_url: URL, path: str) -> URL:
+def join_url(
+    base_url: URL, path: str, add_trailing_slash: bool = False
+) -> URL:
     """Joins base url with a path."""
     base_path = base_url.path
-    return base_url.copy_with(path=join_url_path(base_path, path))
+    path = join_url_path(base_path, path)
+    if add_trailing_slash:
+        path += "/"
+    return base_url.copy_with(path=path)
 
 
 def join_url_path(hostname: str, path: str) -> str:
